@@ -3,6 +3,11 @@ from loguru import logger
 import time 
 import functools
 
+logger.add('logs/runtime_{time}.log', format="{time} {level} {message}", level="INFO",rotation='5 MB')
+
+'''
+该日志不保存
+'''
 def lump_logs(guid,text):
     data_begin = f"\n-------------------- {guid} Begin --------------------\n\n"
     data_end = f"\n-------------------- {guid} End --------------------\n\n"
