@@ -5,8 +5,9 @@ Created on 2020-9-29
 @author: zhys513(254851907@qq.com)
 '''
 import json, os,re
-import os, zipfile
+import fitz, zipfile
 import shutil
+from ..base.logger import logtime  
 
 def clean_text(text):
     text = str(text)
@@ -113,6 +114,37 @@ def save_file(file,save_dir='./tmp'):
     finally:
         file.file.close()
 
+
+'''
+# 将PDF转化为图片
+pdfPath pdf文件的路径
+imgPath 图像要保存的文件夹
+zoom_x x方向的缩放系数
+zoom_y y方向的缩放系数
+rotation_angle 旋转角度
+'''
+@logtime
+def pdf_image(pdfPath,imgPath,zoom_x = 5,zoom_y = 5,rotation_angle = 0):
+    # 打开PDF文件
+    if not os.path.exists(imgPath):
+        os.mkdir(imgPath) 
+        
+    pdf = fitz.open(pdfPath)
+    D = []
+    # 逐页读取PDF
+    for pg in range(0, pdf.pageCount):
+        page = pdf[pg]
+        # 设置缩放和旋转系数
+        trans = fitz.Matrix(zoom_x, zoom_y).preRotate(rotation_angle)
+        pm = page.getPixmap(matrix=trans, alpha=False)
+        # 开始写图像
+        f = os.path.join(imgPath,str(pg)+".png") 
+        pm.writePNG(f) 
+        D.append(f)
+    pdf.close()
+    
+    return D
+
 def copy_dirs(src_path,target_path):
     '''拷贝指定文件夹中的文件到指定目录，没有目录结构'''
     file_count=0
